@@ -7,19 +7,23 @@
 #' @param times integer; number of times
 #' @param wait  number of seconds to wait in between tries.
 #' @param verbose logical; show progress and errors.
+#' @param operation name of the operation used in the error message.
 #'
 #' @return the result of the expression f
 #'
 #' @examples
 #' retry(1)
 #' @export
-retry <- function(f, times = 5, wait = 1, verbose = FALSE) {
+retry <- function(f, times = 5, wait = 1, verbose = FALSE, operation = NULL) {
   times <- as.integer(times)
   
   for (i in seq(times)) {
   suppressWarnings(r <- try(f, silent = !verbose))
-  if (!inherits(r, "try-error")) 
+  if (!inherits(r, "try-error")) { 
+    if (verbose) 
+      cat("Try", i, "of", times, "success.\n")
     return(r)
+  }
   
   if (verbose) 
     cat("Try", i, "of", times, "failed.\n")
@@ -27,8 +31,11 @@ retry <- function(f, times = 5, wait = 1, verbose = FALSE) {
   if (i != times)
     Sys.sleep(wait)
   
-  
   }
-  stop(substitute(f), " failed after ", times, " ties!")
+  
+  if (is.null(operation))
+    operation <- as.character(quote(f))
+  
+  stop(operation, " failed after ", times, " ties!")
   
 }
